summaryrefslogtreecommitdiffstats
path: root/src/dialogs/unclump.cpp
diff options
context:
space:
mode:
authorTed Gould <ted@gould.cx>2008-11-21 05:24:08 +0000
committerTed Gould <ted@canonical.com>2008-11-21 05:24:08 +0000
commit44a3a78fb6a3863c0c7f3c1193837337e68a67e4 (patch)
tree1722ee5ec6f88c881cd4124923354b3c1311501b /src/dialogs/unclump.cpp
parentMerge from trunk (diff)
downloadinkscape-44a3a78fb6a3863c0c7f3c1193837337e68a67e4.tar.gz
inkscape-44a3a78fb6a3863c0c7f3c1193837337e68a67e4.zip
Merge from fe-moved
(bzr r6891)
Diffstat (limited to 'src/dialogs/unclump.cpp')
-rw-r--r--src/dialogs/unclump.cpp28
1 files changed, 18 insertions, 10 deletions
diff --git a/src/dialogs/unclump.cpp b/src/dialogs/unclump.cpp
index 1329fdb5f..2190bf77e 100644
--- a/src/dialogs/unclump.cpp
+++ b/src/dialogs/unclump.cpp
@@ -1,16 +1,13 @@
-#define __UNCLUMP_C__
-
-/*
- * Unclumping objects
- *
- * Authors:
+/** @file
+ * @brief Unclumping objects
+ */
+/* Authors:
* bulia byak
*
* Copyright (C) 2005 Authors
- * Released under GNU GPL
+ * Released under GNU GPL, read the file 'COPYING' for more information
*/
-
#include <algorithm>
#include <map>
#include "libnr/nr-matrix-ops.h"
@@ -35,7 +32,7 @@ unclump_center (SPItem *item)
return i->second;
}
- boost::optional<Geom::Rect> r = item->getBounds(sp_item_i2d_affine(item));
+ Geom::OptRect r = item->getBounds(sp_item_i2d_affine(item));
if (r) {
Geom::Point const c = r->midpoint();
c_cache[SP_OBJECT_ID(item)] = c;
@@ -54,7 +51,7 @@ unclump_wh (SPItem *item)
if ( i != wh_cache.end() ) {
wh = i->second;
} else {
- boost::optional<Geom::Rect> r = item->getBounds(sp_item_i2d_affine(item));
+ Geom::OptRect r = item->getBounds(sp_item_i2d_affine(item));
if (r) {
wh = r->dimensions();
wh_cache[SP_OBJECT_ID(item)] = wh;
@@ -379,3 +376,14 @@ unclump (GSList *items)
}
}
}
+
+/*
+ Local Variables:
+ mode:c++
+ c-file-style:"stroustrup"
+ c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
+ indent-tabs-mode:nil
+ fill-column:99
+ End:
+*/
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :